==> nextcloud-25.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/lt_LT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to receive notifications." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus ir galėtumėte atstatyti slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Papildykite profilį informacija! Pasirinkite paveikslėlį, nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Papildykite profilį informacija! Nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "App recommendation: Nextcloud Calendar" : "Programėlės rekomendacija: Nextcloud kalendorius",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "App recommendation: Nextcloud Contacts" : "Programėlės rekomendacija: Nextcloud adresatai",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "App recommendation: Nextcloud Mail" : "Programėlės rekomendacija: Nextcloud paštas",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
    "App recommendation: Tasks" : "Programėlės rekomendacija: Nextcloud užduotys",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sinchronizuokite užduotis iš įvairių įrenginių naudodami Nextcloud ir taisykite jas tiesiogiai.",
    "App recommendation: Deck" : "Programėlės rekomendacija: Nextcloud darbai",
    "Kanban style organization for personal planning and team projects." : "Kanban stiliaus organizavimas asmeniniam planavimui ir komandiniams projektams.",
    "About" : "Apie",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vediklis, skirtas Nextcloud",
    "Start using {cloudName}" : "Pradėti naudotis {cloudName}",
    "Welcome to {cloudName}!" : "Sveiki atvykę į {cloudName}!",
    "Extend your cloud" : "Išplėskite savo debesiją",
    "Groupware apps like Calendar, Contacts, Mail" : "Grupinio darbo įrangos programėlės, tokios kaip Kalendorius, Adresatai, Paštas",
    "Communication with Nextcloud Talk" : "Bendravimas naudojant Nextcloud Pokalbius",
    "Collaboration apps for document editing" : "Bendradarbiavimo programėlės skirtos dokumentų redagavimui",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Saugumo ir tapatybės nustatymo ypatybės, tokios kaip dviejų faktorių tapatybės nustatymas, SSO ir apsauga nuo išpirkos programinės įrangos.",
    "Browse the App Store" : "Naršyti programėlių parduotuvę",
    "Stay in sync" : "Išlaikykite viską sinchronizuotai",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud suteikia jums prieigą prie failų, nesvarbu, kur bebūtumėte.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai!",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "Desktop client" : "Darbalaukio klientas",
    "iOS app" : "iOS programėlė",
    "Connect your desktop apps to %s" : "Prijunkite savo kompiuterio programas prie %s",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo adresatus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Download macOS/iOS configuration profile" : "Atsisiųsti macOS/iOS konfigūracijos profilį",
    "Get help" : "Gaukite pagalbos",
    "Start contributing" : "Pradėkite talkinti",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Ar norite pamatyti Nextcloud tam tikrą patobulinimą? Ar radote problemą? Norite padėti versti, skleisti žinią ar dokumentuoti Nextcloud?",
    "Become part of the Community" : "Tapkite bendruomenės dalimi",
    "Get more information" : "Gaukite daugiau informacijos",
    "The Nextcloud documentation for home users:" : "Nextcloud dokumentacija namų naudotojams:",
    "User manual" : "Naudotojo vadovas",
    "Admin manual" : "Administratoriaus vadovas",
    "Developer manual" : "Plėtotojo vadovas",
    "You can also ask for help in our community support channels:" : "Taip pat galite prašyti pagalbos mūsų bendruomenės palaikymo kanaluose:",
    "the Nextcloud forums" : "Nextcloud forumuose",
    "A safe home for all your data" : "Saugūs namai visiems jūsų duomenims",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud laiko jūsų valdomus duomenis jums lengvai prieinamoje vietoje. Saugokite savo dokumentus, kalendorių, adresatus ir nuotraukas serveryje, savo kompanijoje, namuose, pas vieną iš mūsų tiekėjų ar jums žinomame duomenų centre.",
    "Host your data and files where you decide" : "Saugokite savo duomenis ir failus ten, kur nuspręsite",
    "Open standards and interoperability" : "Atviri standartai ir funkcinis suderinamumas",
    "100%% open source & community-focused" : "100%% atvirojo kodo ir sutelkta į bendruomenę",
    "Learn more about %s" : "Sužinokite daugiau apie %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s suteikia jums prieigą prie jūsų failų visur, kur bebūtumėte. Mūsų lengvi naudoti darbalaukio ir mobilieji klientai yra prieinami pagrindinėms platformoms visiškai nemokamai.",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Nusistatykite sinchronizavimo kliento programas naudodami <a href=\"%s\">programėlės slaptažodį</a>. Tokiu būdu užtikrinsite, jog galėsite panaikinti prieigą tuo atveju, jei pamesite įrenginį.",
    "Connect other apps to %s" : "Prijunkite kitas programas prie %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Be mobiliųjų programėlių ir darbalaukio kliento programos taip pat galite prijungti bet kokią kitą programinę įrangą, palaikančią WebDAV/CalDAV/CardDAV protokolus į %s.",
    "Server address" : "Serverio adresas",
    "Use this link to connect your apps and desktop client to this server:" : "Naudokite šią nuorodą norėdami prijungti savo programėles bei darbalaukio kliento programas prie šio serverio:",
    "Copy link" : "Kopijuoti nuorodą",
    "App recommendation: Notes" : "Programėlės rekomendacija: Nextcloud užrašai",
    "Distraction-free notes and writing." : "Neblaškantys užrašai ir rašymas.",
    "Android app" : "Android programėlė",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC pokalbių kanale, freenode.net serveryje",
    "Open Standards and Interoperability" : "Atviri standartai ir funkcinis suderinamumas",
    "100%% Open Source & community-focused" : "100%% atvirojo kodo ir sutelkta į bendruomenę"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/lt_LT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Pirmojo paleidimo vediklis",
    "Add your profile information! For example your email is needed to receive notifications." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Pridėkite savo profilio informaciją! Pavyzdžiui, jūsų el. paštas yra reikalingas, kad gautumėte pranešimus ir galėtumėte atstatyti slaptažodį.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Papildykite profilį informacija! Pasirinkite paveikslėlį, nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Papildykite profilį informacija! Nurodykite vardą, pavardę, kad lengviau būtumėte atpažinti šioje platformoje.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Pridėkite savo profilio informaciją! Nustatykite profilio paveikslą, kad lengviau būtumėte atpažinti tarp visų ypatybių.",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
    "App recommendation: Tasks" : "Programėlės rekomendacija: Nextcloud užduotys",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sinchronizuokite užduotis iš įvairių įrenginių naudodami Nextcloud ir taisykite jas tiesiogiai.",
    "App recommendation: Deck" : "Programėlės rekomendacija: Nextcloud darbai",
    "Kanban style organization for personal planning and team projects." : "Kanban stiliaus organizavimas asmeniniam planavimui ir komandiniams projektams.",
    "Connect your calendar" : "Prijunkite savo kalendorių",
    "Connect your contacts" : "Prijunkite savo adresatus",
    "Access files via WebDAV" : "Pasiekite failus per WebDAV",
    "Download macOS/iOS configuration profile" : "Atsisiųsti macOS/iOS konfigūracijos profilį",
    "Desktop client" : "Darbalaukio klientas",
    "iOS app" : "iOS programėlė",
    "About & What's new" : "Apie, kas naujo",
    "A welcome and introduction wizard for Nextcloud" : "Pasisveikinimo ir pristatymo vediklis, skirtas Nextcloud",
    "Close" : "Užverti",
    "More about Nextcloud" : "Daugiau apie Nextcloud",
    "Welcome to {cloudName}!" : "Sveiki atvykę į {cloudName}!",
    "Skip" : "Praleisti",
    "Privacy" : "Privatumas",
    "Community" : "Bendruomenė",
    "Get the apps to sync your files" : "Norėdami sinchronizuoti savo failus, atsisiųskite programėles",
    "Server address" : "Serverio adresas",
    "Use this link to connect your apps and desktop client to this server:" : "Naudokite šią nuorodą norėdami prijungti savo programėles bei darbalaukio kliento programas prie šio serverio:",
    "What's new?" : "Kas naujo?",
    "Share on social media" : "Bendrinti socialiniuose tinkluose",
    "Read more" : "Daugiau skaitykite"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
